==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/lv/base.php <==
<?php

return [
    'About' => 'Par',
    'Admin' => 'Administrācija',
    'Administration' => 'Administrācija',
    'Administrative group' => 'Administrējošā grupa',
    'Advanced' => 'Izvērsti',
    'Approval' => 'Apstiprināšana',
    'Authentication' => 'Autentifikācija',
    'Back to overview' => 'Atpakaļ uz pārskatu',
    'Basic' => 'Pamata',
    'Caching' => 'Kešs',
    'Cronjobs' => 'Cronjob',
    'Default' => 'Noklusēts',
    'Design' => 'Dizains',
    'Files' => 'Faili',
    'General' => 'Galvenais',
    'Groups' => 'Grupas',
    'Logging' => 'Žurnālēšana',
    'Mailing' => 'Ziņojumi',
    'Modules' => 'Moduļi',
    'OEmbed providers' => 'OEmbed provaideri',
    'Permissions' => 'Atļaujas',
    'Proxy' => 'Proxy',
    'Self test' => 'Paštests',
    'Settings' => 'Uzstādījumi',
    'Spaces' => 'Vietas',
    'Statistics' => 'Statistika',
    'User posts' => 'Lietotāju ieraksti',
    'Userprofiles' => 'Lietotāju profili',
    'Users' => 'Lietotāji',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module </strong> administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'Administrators' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logs' => '',
    'Notifications' => '',
    'OEmbed' => '',
    'Open documentation' => '',
    'Pending user registrations' => '',
    'People' => '',
    'Sign up' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
];

==> humhub-1.11.3.tar.gz: humhub-1.11.3/protected/humhub/modules/admin/messages/lv/base.php <==
<?php

return [
    'About' => 'Par',
    'Admin' => 'Administrācija',
    'Administration' => 'Administrācija',
    'Administrative group' => 'Administrējošā grupa',
    'Advanced' => 'Izvērsti',
    'Approval' => 'Apstiprināšana',
    'Authentication' => 'Autentifikācija',
    'Back to overview' => 'Atpakaļ uz pārskatu',
    'Basic' => 'Pamata',
    'Caching' => 'Kešs',
    'Cronjobs' => 'Cronjob',
    'Default' => 'Noklusēts',
    'Design' => 'Dizains',
    'Files' => 'Faili',
    'General' => 'Galvenais',
    'Groups' => 'Grupas',
    'Logging' => 'Žurnālēšana',
    'Mailing' => 'Ziņojumi',
    'Modules' => 'Moduļi',
    'OEmbed providers' => 'OEmbed provaideri',
    'Permissions' => 'Atļaujas',
    'Proxy' => 'Proxy',
    'Self test' => 'Paštests',
    'Settings' => 'Uzstādījumi',
    'Spaces' => 'Vietas',
    'Statistics' => 'Statistika',
    'User not found!' => 'Lietotājs nav atrasts!',
    'Userprofiles' => 'Lietotāju profili',
    'Users' => 'Lietotāji',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module</strong> Administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'Activate' => '',
    'Add Licence Key' => '',
    'Administrators' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Configure' => '',
    'Deactivate' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invalid user state: {state}' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logs' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'Notifications' => '',
    'OEmbed' => '',
    'Open documentation' => '',
    'Pending user registrations' => '',
    'People' => '',
    'Search' => '',
    'Search...' => '',
    'Set as default' => '',
    'Sign up' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'Uninstall' => '',
];
